@@ -150,10 +150,12 @@ def _graphql_fill(
     url: str,
     method: HTTPMethod,
     headers: Dict[str, str],
-    variables: Dict = None,
+    variables: Optional[Dict] = None,
 ) -> RCFile:
     """This function fills the graphql escaperc file."""
 
+    variables = variables or {}
+
     # Now we need to get the user information
     credentials: Dict = {}
     if variables and graphql_document['definitions'][0]['variable_definitions']:
